==> qiho-center-api-2.8.43-20210316.065007-1-sources.jar: com/qiho/center/api/dto/order/BatchOrderDto.java <==
package com.qiho.center.api.dto.order;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * Created by weny.cai on 2018/3/29.
 */
public class BatchOrderDto implements Serializable {

    @ApiModelProperty("上传的文件地址")
    private String fileUrl;

    @ApiModelProperty("处理任务的id")
    private String taskId;

    @ApiModelProperty("文件名称")
    private String fileName;

    @ApiModelProperty("商家id")
    private Long merchantId;

    @ApiModelProperty("任务类型")
    private int taskType;

    /**
     * 操作人
     */
    private String operator;

    /**
     * 操作类型 {@link com.qiho.center.api.enums.order.OrderOperatorTypeEnum}
     */
    private Integer operatorType;


    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public Integer getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(Integer operatorType) {
        this.operatorType = operatorType;
    }

    public String getFileUrl() {
        return fileUrl;
    }

    public void setFileUrl(String fileUrl) {
        this.fileUrl = fileUrl;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public int getTaskType() {
        return taskType;
    }

    public void setTaskType(int taskType) {
        this.taskType = taskType;
    }


}

==> qiho-center-api-2.11.32-20230828.030942-3-sources.jar: com/qiho/center/api/dto/order/BatchOrderDto.java <==
package com.qiho.center.api.dto.order;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * Created by weny.cai on 2018/3/29.
 */
public class BatchOrderDto implements Serializable {

    @ApiModelProperty("上传的文件地址")
    private String fileUrl;

    @ApiModelProperty("处理任务的id")
    private String taskId;

    @ApiModelProperty("文件名称")
    private String fileName;

    @ApiModelProperty("商家id")
    private Long merchantId;

    @ApiModelProperty("任务类型")
    private int taskType;

    /**
     * 操作人
     */
    private String operator;

    /**
     * 操作类型 {@link com.qiho.center.api.enums.order.OrderOperatorTypeEnum}
     */
    private Integer operatorType;

    /** 来源，调用哪个接口过来的{@link com.qiho.center.api.enums.logistics.LogisticsSourceEnum} */
    private Integer source;

    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }

    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public Integer getOperatorType() {
        return operatorType;
    }

    public void setOperatorType(Integer operatorType) {
        this.operatorType = operatorType;
    }

    public String getFileUrl() {
        return fileUrl;
    }

    public void setFileUrl(String fileUrl) {
        this.fileUrl = fileUrl;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public int getTaskType() {
        return taskType;
    }

    public void setTaskType(int taskType) {
        this.taskType = taskType;
    }


}
